#
# spec file for package ghc-pandoc
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name pandoc
%global has_internal_sub_libraries 1
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        3.1.11.1
Release:        150500.11.6.1
Summary:        Conversion between markup formats
License:        GPL-2.0-or-later
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Patch1:         https://github.com/jgm/pandoc/commit/5877ec546df29115163b36de32837f5e08506092.patch#:/CVE-2024-38526-1.patch
Patch2:         https://github.com/jgm/pandoc/commit/59cc5c37251a9a180717474612d6efbd4ad90402.patch#:/CVE-2024-38526-2.patch
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-Glob-devel
BuildRequires:  ghc-JuicyPixels-devel
BuildRequires:  ghc-SHA-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-aeson-pretty-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-attoparsec-devel
BuildRequires:  ghc-base64-bytestring-devel
BuildRequires:  ghc-binary-devel
BuildRequires:  ghc-blaze-html-devel
BuildRequires:  ghc-blaze-markup-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-case-insensitive-devel
BuildRequires:  ghc-citeproc-devel
BuildRequires:  ghc-commonmark-devel
BuildRequires:  ghc-commonmark-extensions-devel
BuildRequires:  ghc-commonmark-pandoc-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-crypton-connection-devel
BuildRequires:  ghc-data-default-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-doclayout-devel
BuildRequires:  ghc-doctemplates-devel
BuildRequires:  ghc-emojis-devel
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-file-embed-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-gridtables-devel
BuildRequires:  ghc-haddock-library-devel
BuildRequires:  ghc-http-client-devel
BuildRequires:  ghc-http-client-tls-devel
BuildRequires:  ghc-http-types-devel
BuildRequires:  ghc-ipynb-devel
BuildRequires:  ghc-jira-wiki-markup-devel
BuildRequires:  ghc-mime-types-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-network-uri-devel
BuildRequires:  ghc-pandoc-types-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-pretty-devel
BuildRequires:  ghc-pretty-show-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-safe-devel
BuildRequires:  ghc-scientific-devel
BuildRequires:  ghc-skylighting-core-devel
BuildRequires:  ghc-skylighting-devel
BuildRequires:  ghc-split-devel
BuildRequires:  ghc-syb-devel
BuildRequires:  ghc-tagsoup-devel
BuildRequires:  ghc-temporary-devel
BuildRequires:  ghc-texmath-devel
BuildRequires:  ghc-text-conversions-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-typst-devel
BuildRequires:  ghc-unicode-collation-devel
BuildRequires:  ghc-unicode-transforms-devel
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-xml-conduit-devel
BuildRequires:  ghc-xml-devel
BuildRequires:  ghc-xml-types-devel
BuildRequires:  ghc-yaml-devel
BuildRequires:  ghc-zip-archive-devel
BuildRequires:  ghc-zlib-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-Diff-devel
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-golden-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-quickcheck-devel
%endif

%description
Pandoc is a Haskell library for converting from one markup format to another.
The formats it can handle include

- light markup formats (many variants of Markdown, reStructuredText, AsciiDoc,
Org-mode, Muse, Textile, txt2tags) - HTML formats (HTML 4 and 5) - Ebook
formats (EPUB v2 and v3, FB2) - Documentation formats (GNU TexInfo, Haddock) -
Roff formats (man, ms) - TeX formats (LaTeX, ConTeXt) - Typst - XML formats
(DocBook 4 and 5, JATS, TEI Simple, OpenDocument) - Outline formats (OPML) -
Bibliography formats (BibTeX, BibLaTeX, CSL JSON, CSL YAML, RIS) - Word
processor formats (Docx, RTF, ODT) - Interactive notebook formats (Jupyter
notebook ipynb) - Page layout formats (InDesign ICML) - Wiki markup formats
(MediaWiki, DokuWiki, TikiWiki, TWiki, Vimwiki, XWiki, ZimWiki, Jira wiki,
Creole) - Slide show formats (LaTeX Beamer, PowerPoint, Slidy, reveal.js,
Slideous, S5, DZSlides) - Data formats (CSV and TSV tables) - PDF (via external
programs such as pdflatex or wkhtmltopdf)

Pandoc can convert mathematical content in documents between TeX, MathML, Word
equations, roff eqn, typst, and plain text. It includes a powerful system for
automatic citations and bibliographies, and it can be customized extensively
using templates, filters, and custom readers and writers written in Lua.

For the pandoc command-line program, see the 'pandoc-cli' package.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version} -p1

%build
%ghc_lib_build_without_haddock

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license COPYING.md
%dir %{_datadir}/%{pkg_name}-%{version}
%dir %{_datadir}/%{pkg_name}-%{version}/citeproc
%dir %{_datadir}/%{pkg_name}-%{version}/citeproc/biblatex-localization
%dir %{_datadir}/%{pkg_name}-%{version}/data
%dir %{_datadir}/%{pkg_name}-%{version}/data/docx
%dir %{_datadir}/%{pkg_name}-%{version}/data/docx/_rels
%dir %{_datadir}/%{pkg_name}-%{version}/data/docx/docProps
%dir %{_datadir}/%{pkg_name}-%{version}/data/docx/word
%dir %{_datadir}/%{pkg_name}-%{version}/data/docx/word/_rels
%dir %{_datadir}/%{pkg_name}-%{version}/data/docx/word/theme
%dir %{_datadir}/%{pkg_name}-%{version}/data/dzslides
%dir %{_datadir}/%{pkg_name}-%{version}/data/odt
%dir %{_datadir}/%{pkg_name}-%{version}/data/odt/META-INF
%dir %{_datadir}/%{pkg_name}-%{version}/data/pptx
%dir %{_datadir}/%{pkg_name}-%{version}/data/pptx/_rels
%dir %{_datadir}/%{pkg_name}-%{version}/data/pptx/docProps
%dir %{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt
%dir %{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/_rels
%dir %{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/notesMasters
%dir %{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/notesMasters/_rels
%dir %{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/notesSlides
%dir %{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/notesSlides/_rels
%dir %{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slideLayouts
%dir %{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slideLayouts/_rels
%dir %{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slideMasters
%dir %{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slideMasters/_rels
%dir %{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slides
%dir %{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slides/_rels
%dir %{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/theme
%dir %{_datadir}/%{pkg_name}-%{version}/data/templates
%dir %{_datadir}/%{pkg_name}-%{version}/data/translations
%{_datadir}/%{pkg_name}-%{version}/COPYRIGHT
%{_datadir}/%{pkg_name}-%{version}/MANUAL.txt
%{_datadir}/%{pkg_name}-%{version}/citeproc/biblatex-localization/*.lbx.strings
%{_datadir}/%{pkg_name}-%{version}/data/abbreviations
%{_datadir}/%{pkg_name}-%{version}/data/bash_completion.tpl
%{_datadir}/%{pkg_name}-%{version}/data/creole.lua
%{_datadir}/%{pkg_name}-%{version}/data/default.csl
%{_datadir}/%{pkg_name}-%{version}/data/docbook-entities.txt
%{_datadir}/%{pkg_name}-%{version}/data/docx/?Content_Types?.xml
%{_datadir}/%{pkg_name}-%{version}/data/docx/_rels/.rels
%{_datadir}/%{pkg_name}-%{version}/data/docx/docProps/app.xml
%{_datadir}/%{pkg_name}-%{version}/data/docx/docProps/core.xml
%{_datadir}/%{pkg_name}-%{version}/data/docx/docProps/custom.xml
%{_datadir}/%{pkg_name}-%{version}/data/docx/word/_rels/document.xml.rels
%{_datadir}/%{pkg_name}-%{version}/data/docx/word/_rels/footnotes.xml.rels
%{_datadir}/%{pkg_name}-%{version}/data/docx/word/comments.xml
%{_datadir}/%{pkg_name}-%{version}/data/docx/word/document.xml
%{_datadir}/%{pkg_name}-%{version}/data/docx/word/fontTable.xml
%{_datadir}/%{pkg_name}-%{version}/data/docx/word/footnotes.xml
%{_datadir}/%{pkg_name}-%{version}/data/docx/word/numbering.xml
%{_datadir}/%{pkg_name}-%{version}/data/docx/word/settings.xml
%{_datadir}/%{pkg_name}-%{version}/data/docx/word/styles.xml
%{_datadir}/%{pkg_name}-%{version}/data/docx/word/theme/theme1.xml
%{_datadir}/%{pkg_name}-%{version}/data/docx/word/webSettings.xml
%{_datadir}/%{pkg_name}-%{version}/data/dzslides/template.html
%{_datadir}/%{pkg_name}-%{version}/data/epub.css
%{_datadir}/%{pkg_name}-%{version}/data/init.lua
%{_datadir}/%{pkg_name}-%{version}/data/odt/META-INF/manifest.xml
%{_datadir}/%{pkg_name}-%{version}/data/odt/content.xml
%{_datadir}/%{pkg_name}-%{version}/data/odt/manifest.rdf
%{_datadir}/%{pkg_name}-%{version}/data/odt/meta.xml
%{_datadir}/%{pkg_name}-%{version}/data/odt/mimetype
%{_datadir}/%{pkg_name}-%{version}/data/odt/styles.xml
%{_datadir}/%{pkg_name}-%{version}/data/pptx/?Content_Types?.xml
%{_datadir}/%{pkg_name}-%{version}/data/pptx/_rels/.rels
%{_datadir}/%{pkg_name}-%{version}/data/pptx/docProps/app.xml
%{_datadir}/%{pkg_name}-%{version}/data/pptx/docProps/core.xml
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/_rels/presentation.xml.rels
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/notesMasters/_rels/notesMaster1.xml.rels
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/notesMasters/notesMaster1.xml
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/notesSlides/_rels/notesSlide1.xml.rels
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/notesSlides/_rels/notesSlide2.xml.rels
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/notesSlides/notesSlide1.xml
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/notesSlides/notesSlide2.xml
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/presProps.xml
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/presentation.xml
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slideLayouts/_rels/slideLayout1.xml.rels
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slideLayouts/_rels/slideLayout10.xml.rels
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slideLayouts/_rels/slideLayout11.xml.rels
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slideLayouts/_rels/slideLayout2.xml.rels
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slideLayouts/_rels/slideLayout3.xml.rels
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slideLayouts/_rels/slideLayout4.xml.rels
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slideLayouts/_rels/slideLayout5.xml.rels
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slideLayouts/_rels/slideLayout6.xml.rels
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slideLayouts/_rels/slideLayout7.xml.rels
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slideLayouts/_rels/slideLayout8.xml.rels
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slideLayouts/_rels/slideLayout9.xml.rels
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slideLayouts/slideLayout1.xml
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slideLayouts/slideLayout10.xml
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slideLayouts/slideLayout11.xml
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slideLayouts/slideLayout2.xml
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slideLayouts/slideLayout3.xml
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slideLayouts/slideLayout4.xml
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slideLayouts/slideLayout5.xml
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slideLayouts/slideLayout6.xml
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slideLayouts/slideLayout7.xml
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slideLayouts/slideLayout8.xml
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slideLayouts/slideLayout9.xml
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slideMasters/_rels/slideMaster1.xml.rels
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slideMasters/slideMaster1.xml
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slides/_rels/slide1.xml.rels
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slides/_rels/slide2.xml.rels
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slides/_rels/slide3.xml.rels
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slides/_rels/slide4.xml.rels
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slides/slide1.xml
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slides/slide2.xml
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slides/slide3.xml
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/slides/slide4.xml
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/tableStyles.xml
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/theme/theme1.xml
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/theme/theme2.xml
%{_datadir}/%{pkg_name}-%{version}/data/pptx/ppt/viewProps.xml
%{_datadir}/%{pkg_name}-%{version}/data/templates/affiliations.jats
%{_datadir}/%{pkg_name}-%{version}/data/templates/article.jats_publishing
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.asciidoc
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.biblatex
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.bibtex
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.chunkedhtml
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.commonmark
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.context
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.docbook4
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.docbook5
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.dokuwiki
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.dzslides
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.epub2
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.epub3
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.haddock
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.html4
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.html5
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.icml
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.jats_archiving
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.jats_articleauthoring
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.jats_publishing
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.jira
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.latex
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.man
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.markdown
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.markua
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.mediawiki
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.ms
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.muse
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.opendocument
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.opml
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.org
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.plain
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.revealjs
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.rst
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.rtf
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.s5
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.slideous
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.slidy
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.tei
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.texinfo
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.textile
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.typst
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.xwiki
%{_datadir}/%{pkg_name}-%{version}/data/templates/default.zimwiki
%{_datadir}/%{pkg_name}-%{version}/data/templates/definitions.typst
%{_datadir}/%{pkg_name}-%{version}/data/templates/styles.citations.html
%{_datadir}/%{pkg_name}-%{version}/data/templates/styles.html
%{_datadir}/%{pkg_name}-%{version}/data/templates/template.typst
%{_datadir}/%{pkg_name}-%{version}/data/translations/*.yaml

%files devel -f %{name}-devel.files
%doc AUTHORS.md README.md changelog.md

%changelog
* Thu Jun  5 2025 psimons@suse.com
- Apply "CVE-2024-38526-1.patch" and "CVE-2024-38526-2.patch" to
  remove use of remote Javascript code from cdn.polyfill.io from
  generated HTML files. polyfill.js was a popular open source
  library to support older browsers. 100K+ sites embed it using the
  cdn.polyfill.io domain. However, in February 2024, a Chinese
  company bought the domain and since then, this domain was caught
  injecting malware on mobile devices via any site that embeds
  cdn.polyfill.io. [bsc#1227690, CVE-2024-38526]
* Sat Jan  6 2024 psimons@suse.com
- Update pandoc to version 3.1.11.1.
  [#]# pandoc 3.1.11.1 (2023-01-05)
  * Docx reader:
    + Fix HYPERLINK with only switch and no argument (#9246).
  * Org reader:
    + Parse caption and label for grid tables (#9279).
  * MediaWiki reader:
    + Handle multiline math in list items (#9293).
  * OPML writer:
    + Respect `--wrap` options & `--columns` in contents of notes (#9297).
  * ODT/OpenDocument writers:
    + Properly handle highlighting styles (#9287). These styles were
    going into an `office:styles` element in `content.xml`, but this
    is invalid. Instead they must go in `styles.xml`. The variable
    `highlighting-styles` no longer has any effect on the default
    opendocument template, and highlighting styles are not included
    in `opendocument` output.
  * Markdown writer:
    + Add table identifier at end of caption if present (#9279).
  * Text.Pandoc.PDF:
    + Expand list of environment variables to display in verbose output
    (#9303).
    + Ensure that we find all the LaTeX warnings requiring a rerun (#9284).
    This should fix a regression from 3.1.9 that led to incorrect
    alignments in tables (and possibly other issues).
  * Docx writer:
    + Ensure that pandoc's output validates (Edwin Török, #9273, #9269,
    John MacFarlane, #9265, #9266, #9264).
    + Don't emit empty table rows, which seem to cause problems for
    Word (#9224).
  * LaTeX writer:
    + Omit superfluous page locator label when used with `--natbib` or
    `--biblatex` (#9275). These will treat a bare number as a
    page locator, and they will be able to localize it. Note that the
    recognition of the locator label is locale-sensitive; if `lang` is
    `de`, then `S. 33` is a page reference, and `p. 33` is not!
  * Text.Pandoc.Chunks: Fine tune `makeChunks` (#9281).
    + Ensure that chunks not based on sections (those with the
    "preamble" class) get unique identifiers, by appending chunk number.
    + This will also ensure that they get unique path names when
    the path is generated from the identifier.
  * Default HTML5 template: remove html5shiv (and support for IE < 9).
  * Makefile:
    + Fix `make quick-stack`: `j` was expecting a number (Edwin Török).
    + Run built pandoc (instead of pandoc in path).
    + Add `validate-epub` target, using `epubcheck` to test the golden files.
    + Add `validate-docx-golden-tests` target.
  [#]# pandoc 3.1.11 (2023-12-15)
  * Typst writer:
    + Emit `;` after typst code, unless followed by space (#9252).
    Otherwise there's the potential that the typst code will swallow
    up a following character.
  * Text.Pandoc.Logging:
    + Add `MakePDFWarning` constructor to LogMessage [API change].
    + Add `MakePDFInfo` constructor to LogMessage [API change].
  * Text.Pandoc.PDF:
    + LaTeX warnings are passed on to the user as warnings.
    + Use `report` with `MakePDFWarning` and `MakePDFInfo` to relay
    verbose information and warnings, instead of writing directly
    to stderr.
    + Parse logs to determine whether additional runs needed, instead of
    running a fixed number of times (#9255). (The number of times
    that was appropriate given pandoc's default templates didn't
    always work for custom templates, and thus pandoc 3.1.10's
    change in the number of runs led to some regressions in PDF
    production.)
  * Makefile: in `make prelease`, add checks that pandoc-cli and
    pandoc have the same version, that pandoc-cli depends on this
    exact version of pandoc, that there is an entry for this version
    in the changelog, and that the version numbers in the
    generated man pages are correct.
  * Regenerate man pages with pandoc 3.1.10. This properly escapes hyphens
    and fixes version numbers in man pages for `pandoc-server` and
    `pandoc-lua`.
  * Depend on texmath 0.12.8.6. This omits unneeded `lr`s in typst
    math output.
  * Depend on typst 0.5. This allows the typst reader to support
    multiline strings, the version type, and the `as`
    keyword with `import`.
  [#]# pandoc 3.1.10 (2023-12-12)
  * Link pandoc-cli version to pandoc version. Henceforth pandoc-cli's
    version will be synchronized with pandoc's, and pandoc-cli will
    depend on an exact pandoc version. This will avoid confusion by
    ensuring that `cabal install pandoc-cli-X.Y.Z` installs pandoc
    version X.Y.Z. It will make things more straightforward for
    upstream packagers (see #9232). This scheme does not follow the
    Haskell PVP, but that should cause no harm, because this package
    does not expose a library.
  * Add `alerts` markdown extension. This enables GitHub style markdown
    alerts as a commonmark extension. This extension is now default for
    `gfm`. It can't be used with `markdown`, only with `commonmark` and
    variants.
  * Markdown reader:
    + Preserve newlines in math instead of changing to spaces.
    Otherwise we can get unwanted results if there's
    a `%%` comment (#9193).
    + Make attributes work with reference links (#9171).
  * HTML reader:
    + Improve handling of invalidly nested sublists (#9187, cf. #8150).
  * MediaWiki reader:
    + Allow attribute keys with hyphens (#9178).
  * ODT reader:
    + Support attr `text:continue-numbering` (#8979, Stephan Meijer).
  * Typst reader:
    + Allow references (e.g. `@foo`) to become citations
    if there is no corresponding label in the document.
    + Collapse adjacent `cite` elements.
    + Handle supplements in `cite`.
    + Change `cite` (only one key allowed, a label) (typst 0.9 breaking change).
    + Support `quote` element (typst 0.9).
  * LaTeX reader:
    + Handle otherlanguage environment and language-name environments like
    `\begin{french}...\end{french}` (#9202).
    + Fix theorem label parsing (#8872, Hikaru Ibayashi).
  * Docx reader:
    + Unwrap content of shaped textboxes (Stephan Meijer, #9214).
    + Improve handling of `w:sym` (#9220). We now look up symbols in symbol
    fonts using the table defined at Text.Pandoc.Readers.Docx.Symbols.
    + Add unexported module Text.Pandoc.Readers.Docx.Symbols. This gives us a
    table to use to resolve characters included in docx via `w:sym` element.
  * Man reader:
    + Properly handle `.sp` macro inside lists and block quotes (#9201).
  * LaTeX writer:
    + Fix bug with big footnotes inside emphasis (#8982, Hikaru Ibayashi).
    + Handle identifiers inside heading contents. `\phantomsection` can't
    be used in this case, so we need `\hypertarget` (#9209).
  * LaTeX template:
    + Include `bookmark` package unconditionally. This package
    produces better PDF bookmarks than `hyperref` and does it on the
    first pass.
  * Typst writer:
    + Use `quote` for block quotes.
    + Support `--toc-depth` as in other writers (#9242).
    + Put inline image dimensions on enclosing box, not image (#9104).
    + Better handling of tables with captions (#9194).
    We now put these in a figure with a caption argument.
    + Update typst writer to typst 0.9 citation format (#9188).
  * Typst template:
    + Remove custom definition of `blockquote` in default template.
    (We now use built-in `quote`.)
    + Support table of contents.
    + Support csl (#9186, Ian Max Andolina). Typst now supports CSL for its
    native citation engine, so pandoc should use a specified `csl`
    style in the template, falling back to `bibliographystyle` if
    `csl` is not specified.
  * Docx writer:
    + Use different style for block quotes in notes (#9243).
    Using "Footnote Block Text" for the style name, so it can be
    given a different font size if footnotes are.
    + Allow embedded fonts to be used in reference.docx (#6728).
  * HTML5 writer:
    + To conform to validator's expectations, `doc-footnote` role is used
    with `aside` and `doc-endnotes` with `section`.
    + `aside` is used only for notes at ends of sections or blocks;
    if all the notes come at the end of the document, `section` is
    used so we can have the `doc-endnotes` role.
  * JATS writer:
    + Handle case where there is material after refs div (#9166). Previously in
    such cases the references were not being moved to back matter.
  * Ms writer:
    + Don't do normal escapes in filename arguments for PSPIC etc.
  * T.P.RoffChar: escape `-` as `\-`. The `groff_man (7)` man page indicates
    that `-` characters will be treated as typographic hyphens and are not
    appropriate for cases where the output should be copy-pasteable as an
    ASCII hyphen-minus character.  (E.g. in command line options.)
    However, until a recent update groff man did not actually do this;
    it treated `-` and `\-` the same.  With the new update (1.23.0)
    the two are distinguished (see https://lwn.net/Articles/947941/
    for background), so now it is important that pandoc escape `-`.
  * Text.Pandoc.Extension: add `Ext_alerts` constructor [API change].
  * Text.Pandoc.PDF: We now default to running LaTeX only
    once in producing a PDF (instead of twice). This is made possible by the
    shift to the `bookmark` package, which does not require a second pass for
    PDF bookmarks. If a table of contents is present, we still have to run
    three times to get the page numbers, and if beamer is used we still do a
    minimum of two runs.
  * Text.Pandoc.Shared:
    + `renderTags'`: use minimized tag for `rect`.
    + Allow svg `path` element to be minimized.
    + Export `combineAttr` [API change].
    + Improve `isTightList` so that it recognizes an item containing only a list
    which is itself tight as potentially an item in a tight list (#9161).
  * Text.Pandoc.MIME: Ensure we use `.svg` not `.svgz` as extension
    for `image/svg+xml` mime type. This fixes issues with embedded
    SVG images in docx output, among other things (#9195).
  * Text.Pandoc.Class: `openURL` improvements for data uris.
    Only treat data URI as `base64` if ';base64' is specified.
    Otherwise treat as UTF-8 (not 100%% reliable but should cover most
    other cases). Strip off `;base64` (or `;charset=...` or whatever)
    from mime type (#9195).
  * Text.Pandoc.SelfContained: Improve treatment of embedded SVGs
    (#9206, #8948).
    + Ensure unique ids for elements by prefixing SVG id.
    + Ensure SVG `id` attribute except when `use` element is used.
    + Remove `width`, `height` attributes from svg element when `use`
    element is used. Instead, add `width` and `height` 100%% to the
    `use` element. This seems to get the sizing right.
  * Text.Pandoc.Citeproc: Don't link citations if
    `suppress-bibliography` specified, for there will be nothing to
    link to (#9163).
  * epub.css: add styling for sup and sub (#9160).
  * Switch from `base64` to `base64-bytestring` (#9233).
  * Use newest versions of commonmark, commonmark-extensions,
    commonmark-pandoc, texmath, typst, skylighting, skylighting-core.
  * Benchmark: use standalone documents for reader tests.
    Otherwise typst reader benchmark fails. Note: this means that we are now
    parsing longer documents, so bench results on readers won't be comparable
    to before.
  * MANUAL.txt: update defaults file docs for bibliography fields (#9173).
    Recommend using top-level `bibliography` `csl`, etc. instead
    of a nested `metadata` field. Reason: `${USERDATA}` and `${HOME}`
    are only expanded in these contexts, not in `metadata`.
  * Move man pages to pandoc-cli package (#9245).
* Sat Oct 28 2023 psimons@suse.com
- Add pandoc at version 3.1.9.
